==> eiffelstudio-23.09.10.7341.tar: F_code/C2/by67.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by67.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_array_natural_16 */
void F69_2165 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_16", 68, Current, 3, 3, 1507);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3134, 0x00).id, 3134, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3135_34541(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3135_34601(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3135_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3008_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3008_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32 */
void F69_2169 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_32", 68, Current, 3, 3, 1511);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3134, 0x00).id, 3134, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3135_34541(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3135_34602(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3135_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3008_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3008_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32_with_integer_32 */
void F69_2171 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_natural_32_with_integer_32", 68, Current, 3, 3, 1513);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3134, 0x00).id, 3134, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3135_34541(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3135_34606(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3135_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3008_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3008_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_array_integer_16 */
void F69_2174 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_array_integer_16", 68, Current, 3, 3, 1516);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3134, 0x00).id, 3134, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3135_34541(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3135_34605(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3135_34568(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3008_33858(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3008_33866(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

void EIF_Minit67 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C2/by67.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by67.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_natural_16 */
void F70_2256 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_natural_16", 69, Current, 3, 3, 1560);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3153, 0x00).id, 3153, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3154_34786(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3154_34846(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3154_34813(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3029_34103(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3029_34111(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_natural_32 */
void F70_2257 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_natural_32", 69, Current, 3, 3, 1561);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3153, 0x00).id, 3153, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3154_34786(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3154_34847(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3154_34813(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3029_34103(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3029_34111(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_16 */
void F70_2260 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_integer_16", 69, Current, 3, 3, 1564);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3153, 0x00).id, 3153, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3154_34786(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	RTHOOK(2);
	F3154_34850(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3154_34813(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3029_34103(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3029_34111(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_32 */
void F70_2261 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,arg1);
	RTLR(3,loc2);
	RTLR(4,Current);
	RTLIU(5);
	
	RTEAA("put_integer_32", 69, Current, 3, 3, 1565);
	RTGC;
	RTHOOK(1);
	loc1 = RTLNS(eif_new_type(3153, 0x00).id, 3153, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F3154_34786(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	RTHOOK(2);
	F3154_34851(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	RTHOOK(3);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	loc3 = F3154_34813(RTCW(loc1), ((EIF_INTEGER_32) 0L), ti4_1);
	RTHOOK(4);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F3029_34103(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	RTHOOK(5);
	loc2 = F3029_34111(RTCW(arg1));
	RTHOOK(6);
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTHOOK(8);
	RTLE;
	RTEE;
}

void EIF_Minit67 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
